=======
Credits
=======

Thonny is thankful to:

Its home
--------
Thonny grew up in University of Tartu (https://www.ut.ee), Institute of Computer Science (https://www.cs.ut.ee).

Supporters
----------
* Development of several features in Thonny 3.0 and 3.3 was proposed and supported by Raspberry Pi Foundation (https://www.raspberrypi.org).
* Since September 2018, development of Thonny is partially supported by Cybernetica AS (https://cyber.ee).

Several companies and organizations have provided us with free hardware for testing Thonny (and for having fun):

* Phidgets Education (https://www.phidgets.com/education/)
* Adafruit (https://www.adafruit.com/)
* Raspberry Pi Foundation (https://www.raspberrypi.org)
* M5Stack (https://m5stack.com/)
* Micro:bit educational foundation (https://microbit.org/)
* Calliope (https://calliope.cc/en)
* @bwshockley (https://minifigboards.com/)

Python
------
It's a really nice language for teaching programming. It also has some nice technical properties, that made Thonny's program animation features pleasure to implement.

Libraries, resources and tools
------------------------------
* asttokens (https://github.com/gristlabs/asttokens) provides source locations to AST nodes.
* jedi (http://jedi.readthedocs.io) is used for code completion, go to definition, etc.
* pylint (https://www.pylint.org/) is used as one of the engines behind warnings presented by the Assistant.
* mypy (http://mypy-lang.org/) is used, just like pylint, as a warning engine in the Assistant.
* pyserial (https://github.com/pyserial/pyserial) is used for communicating with MicroPython devices.
* docutils (http://docutils.sourceforge.net/) is used for parsing help content written in reStructuredText.
* send2trash (https://github.com/hsoft/send2trash) is used by the Files view.
* certifi (https://pypi.python.org/pypi/certifi) provides SSL certs for bundled Python in Linux and Mac.
* distro (https://pypi.python.org/pypi/distro) is optionally used for detecting Linux version in About dialog.
* paramiko (https://pypi.org/project/paramiko) is optionally used for writing and running code on remote machines.
* websockets (https://pypi.org/project/websockets) is optionally used for communicating with MicroPython devices over WebREPL.
* Most icons are taken from Eclipse project (https://www.eclipse.org/, https://github.com/eclipse/eclipse.platform.debug/tree/master/org.eclipse.debug.ui/icons/full/, https://github.com/eclipse/eclipse.platform.ui/tree/master/bundles/org.eclipse.ui/icons/full/, https://github.com/eclipse/eclipse.jdt.ui/tree/master/org.eclipse.jdt.ui/icons/full/), on Linux, some are overridden by Tango icons (http://tango.freedesktop.org/)
* POEditor (https://poeditor.com/) is used for managing translations of UI strings.
* https://github.com/hlovatt/PyBoardTypeshed

Source contributors, sponsors, advisors, translators and frequent bug-reporters
-------------------------------------------------------------------------------
* adzierzanowski
* Aivar Annamaa
* Albin
* Alar Leemet
* Aleks ANDRÉ
* Alex Hall
* Alexandre Barrozo do Amaral Villares
* Algent Albrahimi
* Anatoly Techtonik
* Anders Pamdal
* Andrea Ferrari
* Andrew Scheller
* André Roberge
* Andy Piper
* Ankith
* Antonio Carlos
* atesin
* Augene J. Pak
* Austin Bart
* Avag. sayan
* badukaire
* Bui Huy Quang
* borpol
* CADTEC GmbH (cadtec.ch)
* cefn
* Celso Isayah Dias
* Chad Purdy
* codemee
* Collision Detection
* cspaier
* cubimon
* Curtis Wang
* Dominic Twyman
* Dominik George
* Donald Butt
* Duncan Ogilvie (@mrexodia)
* Eliot Blennerhassett
* Emanuel Angelo
* Fabianus.c
* Farshid Meidani
* Filip Schouwenaars
* Fizban
* freddii
* fstengel
* Gabriel Slørdahl
* Gagan Saksena
* Georges Khaznadar
* Helmut Ascheid
* Hyungseok Choi
* IhorNehrutsa
* Ingo Blechschmidt
* Isaac Levy (@isaacl)
* Ivanhercaz
* Ivan.schamann
* Илья Кругликов
* Jarek Miszczak
* Jens Diemer
* jharris1993
* Juan Falgueras
* Juhan Oskar Hennoste (@FeldrinH)
* Jonathan Campbell
* Jordan Williams
* jose1711
* José Carlos García
* Karolina Surma (@befeleme)
* Kaspar Papli
* Kauri Raba
* kr-g
* Laszlo Kocsis
* Lrasinen
* M Burak Kalkan
* Marcelo de Gomensoro Malheiros
* Marian-Silviu Iuga
* Marie Roald
* Marko Ristin
* Martin Rommel
* Matt Iversen
* Miro Hrončok
* NathanBnm
* Nicolas Despres
* Pavel Minaev
* Peter Marshall
* Peter Mawhorter (@solsword)
* Petr. moses
* Phil Duby
* phr0gger
* Pop Vasile Alexandru
* Radim
* Rene Lehtma
* Rune Langøy
* Saishen, Inc.
* Sam Warmuth
* Sami Almuhammady
* sailslack
* Scott Blackledge
* segalion
* Simon Gijsen
* Simon Long
* sourceperl
* speedy-10
* Stefan Rothe
* Stewart Russell (@scruss)
* Suk-Hyung Hwang
* Sven Duzont
* Syed Nasim
* Taavi Ilp
* tabreturn
* TANAKA Masayuki
* Thomas Helmuth
* TooLazy0x00
* Toomas Mölder
* Tristan Bunn
* Tusamten
* Vytenis (svajoklis-1)
* Xin Rong
* YEON
* 丁向阳 (Ding-XiangYang)
* 涂紳騰 (Shen-Teng Tu)
* 張文宏 (Wen-Hung, Chang)

Please let us know if we have forgotten to add your name to this list! Also, let us know if you want to remove your name.
